<?php
/**
 * @package Safe_Function_Call
 * @author Scott Reilly
 * @version 1.1.7
 */
/*
Plugin Name: Safe Function Call
Version: 1.1.7
Plugin URI: http://coffee2code.com/wp-plugins/safe-function-call/
Author: Scott Reilly
Author URI: http://coffee2code.com/
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Description: Safely and easily call functions that may not be available (such as those provided by a plugin that gets deactivated).

Compatible with WordPress 1.5 through 3.5+.

=>> Read the accompanying readme.txt file for instructions and documentation.
=>> Also, visit the plugin's homepage for additional information and updates.
=>> Or visit: http://wordpress.org/extend/plugins/safe-function-call/

*/

/*
	Copyright (c) 2007-2013 by Scott Reilly (aka coffee2code)

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

if ( ! function_exists( '_sfc' ) ) :
	/**
	 * Safely invoke the function by the name of $function_name.  Any additional
	 * arguments will get passed to $function_name().  If $function_name() does
	 * not exist, nothing is displayed and no error is generated.
	 *
	 * @param string $function_name Name of the function to call
	 * @return mixed If $function_name exists as a function, returns whatever that function returns. Otherwise, returns nothing.
	 */
	function _sfc( $function_name ) {
		if ( ! function_exists( $function_name ) )
			return;
		$args = array_slice( func_get_args(), 1 );
		return call_user_func_array( $function_name, $args );
	}
endif;


if ( ! function_exists( '_sfce' ) ) :
	/**
	 * Safely invoke the function by the name of $function_name and echo its return
	 * value .  Any additional arguments will get passed to $function_name().  If
	 * $function_name() does not exist, nothing is displayed and no error is
	 * generated.
	 *
	 * This functions is the same as _sfc() except that it echoes the return value
	 * of $function_name() before returning that value.
	 *
	 * @param string $function_name Name of the function to call
	 * @return mixed If $function_name exists as a function, returns whatever that function returns. Otherwise, returns nothing.
	 */
	function _sfce( $function_name ) {
		if ( ! function_exists( $function_name ) )
			return;
		$args = func_get_args();
		$value = call_user_func_array( '_sfc', $args );
		if ( $value )
			echo $value;
		return $value;
	}
endif;


if ( ! function_exists( '_sfcf' ) ) :
	/**
	 * Safely invoke the function by the name of $function_name.  Any additional
	 * arguments will get passed to $function_name().  If $function_name() does
	 * not exist, then an alternative function is called.
	 *
	 * This functions is the same as _sfc() except that if the intended function
	 * does not exist, then an alternative function is invoked (if it exists
	 * itself).
	 *
	 * @param string $function_name Name of the function to call
	 * @param string $function_if_missing (optional) Name of the alternative function to call if $function_name does not exists
	 * @return mixed If $function_name exists as a function, returns whatever that function returns. Otherwise, returns nothing.
	 */
	function _sfcf( $function_name, $function_if_missing = null ) {
		$args = array_slice( func_get_args(), 2 );
		if ( ! function_exists( $function_name ) ) {
			if ( function_exists( $function_if_missing ) ) {
				$args = array_merge( array( $function_name ), $args );
				return call_user_func_array( $function_if_missing, $args );
			}
			return;
		}
		return call_user_func_array( $function_name, $args );
	}
endif;


if ( ! function_exists( '_sfcm' ) ) :
	/**
	 * Safely invoke the function by the name of $function_name.  Any additional
	 * arguments will get passed to $function_name().  If $function_name() does
	 * not exist, then an alternative function is called with identical arguments.
	 *
	 * This functions is the same as _sfc() except that if the intended function
	 * does not exist, then a string is echoed (if provided).
	 *
	 * @param string $function_name Name of the function to call
	 * @param string $msg_if_missing (optional) String to be echoed if $function_name does not exist
	 * @return mixed If $function_name exists as a function, returns whatever that function returns.  Otherwise, returns nothing.
	 */
	function _sfcm( $function_name, $msg_if_missing = '' ) {
		if ( ! function_exists( $function_name ) ) {
			if ( $msg_if_missing )
				echo $msg_if_missing;
			return;
		}
		$args = array_slice( func_get_args(), 2 );
		return call_user_func_array( $function_name, $args );
	}
endif;
